@@ -103,7 +103,7 @@ parsePRIMO <- function(x, planInfo=FALSE, courseAsID=FALSE, ...) {
         doseSD    <- NA_real_
 
         volumeUnit <- getVolUnit(strct)
-        volumeUnit <- if(grepl("^CM.+", volumeUnit)) {
+        volumeUnit <- if(grepl("^CM.+", volumeUnit, useBytes=TRUE)) {
             "CC"
         } else if(grepl("^%", volumeUnit)) {
             "PERCENT"
