@@ -25,7 +25,7 @@ shinyApp(
     ui=dashboardPage(
         # theme = "custom.css",
         title="Analyze dose-volume histograms using DVHmetrics",
-        dark=FALSE,
+        dark=NULL,
         help=FALSE,
         sidebar=source("app_ui_sidebar.R", encoding="UTF8")$value,
         header=dashboardHeader(
@@ -69,10 +69,10 @@ shinyApp(
     #####-----------------------------------------------------------------------
     server=function(input, output, session) {
         session$onSessionEnded(stopApp)
-        
+
         ## directory where current DVH data is saved
         DVHdir <- tempdir()
-        
+
         ## reactive conductor
         DVH <- reactive({
             input$applyData
@@ -114,21 +114,21 @@ shinyApp(
                         NULL
                     }
                 }
-                
+
                 ## add representation by structure
                 DVHdataByStruct <- if(!is.null(DVHdata)) {
                     DVHmetrics:::reorgByPat(DVHdata, byPat=FALSE)
                 } else {
                     NULL
                 }
-                
+
                 DvHcurr <- list(DVH=DVHdata, DVHbyStruct=DVHdataByStruct)
                 setwd(DVHdir)
                 saveRDS(DvHcurr$DVH, file="DVHprev.rds")
                 return(DvHcurr)
             })
         })
-        
+
         output$DVHinfo <- renderPrint({
             dvh <- DVH()$DVH
             if(!is.null(dvh)) {
@@ -141,7 +141,7 @@ shinyApp(
                 invisible(NULL)
             }
         })
-        
+
         output$metrSelStruct <- renderUI({
             dvh <- DVH()$DVH
             if(!is.null(dvh)) {
@@ -153,7 +153,7 @@ shinyApp(
                 NULL
             }
         })
-        
+
         observeEvent(
             eventExpr=input$metrSelStructAll,
             handlerExpr= {
@@ -173,7 +173,7 @@ shinyApp(
                 }
             }
         )
-        
+
         output$metrSelPat <- renderUI({
             dvh <- DVH()$DVH
             if(!is.null(dvh)) {
@@ -185,7 +185,7 @@ shinyApp(
                 NULL
             }
         })
-        
+
         ## https://stackoverflow.com/a/35044158
         observeEvent(
             eventExpr=input$metrSelPatAll,
@@ -206,7 +206,7 @@ shinyApp(
                 }
             }
         )
-        
+
         output$plotSelStruct <- renderUI({
             dvh <- DVH()$DVH
             if(!is.null(dvh)) {
@@ -218,7 +218,7 @@ shinyApp(
                 NULL
             }
         })
-        
+
         observeEvent(
             eventExpr=input$plotSelStructAll,
             handlerExpr= {
@@ -238,7 +238,7 @@ shinyApp(
                 }
             }
         )
-        
+
         output$plotSelPat <- renderUI({
             dvh <- DVH()$DVH
             if(!is.null(dvh)) {
@@ -250,7 +250,7 @@ shinyApp(
                 NULL
             }
         })
-        
+
         observeEvent(
             eventExpr=input$plotSelPatAll,
             handlerExpr= {
@@ -270,7 +270,7 @@ shinyApp(
                 }
             }
         )
-        
+
         output$metrics <- DT::renderDataTable({
             dvh        <- DVH()$DVH
             sortOpts   <- c('1'="observed", '2'="structure", '3'="metric", '4'="patID")
@@ -303,12 +303,13 @@ shinyApp(
             EUDa    <- if(input$metrEUDa  != "") { as.numeric(input$metrEUDa)  } else { NULL }
             EUDfd   <- if(input$metrEUDfd != "") { as.numeric(input$metrEUDfd) } else { NULL }
             EUDab   <- if(input$metrEUDab != "") { as.numeric(input$metrEUDab) } else { NULL }
-            
-            NTCPtype    <- c("probit", "logit", "poisson")[as.numeric(input$metrNTCPtype)]
+
+            NTCPtype    <- c("probit", "logit", "poisson", "relative_seriality")[as.numeric(input$metrNTCPtype)]
             NTCPtd50    <- if(input$metrNTCPtd50    != "") { as.numeric(input$metrNTCPtd50)    } else { NULL }
             NTCPn       <- if(input$metrNTCPn       != "") { as.numeric(input$metrNTCPn)       } else { NULL }
             NTCPm       <- if(input$metrNTCPm       != "") { as.numeric(input$metrNTCPm)       } else { NULL }
             NTCPgamma50 <- if(input$metrNTCPgamma50 != "") { as.numeric(input$metrNTCPgamma50) } else { NULL }
+            NTCPs       <- if(input$metrNTCPs       != "") { as.numeric(input$metrNTCPs)       } else { NULL }
             
             sortSel <- input$metrSortBy
             sortBy <- if(length(sortSel) > 0) {
@@ -324,8 +325,8 @@ shinyApp(
                              sortBy=sortBy,
                              interp=interp,
                              EUDa=EUDa, EUDfd=EUDfd, EUDab=EUDab,
-                             NTCPtype=NTCPtype, NTCPtd50=NTCPtd50, NTCPn=NTCPn, NTCPm=NTCPm, NTCPgamma50=NTCPgamma50,
-                             TCPtype=NTCPtype, TCPtcd50=NTCPtd50,  TCPn=NTCPn,  TCPm=NTCPm,  TCPgamma50=NTCPgamma50)
+                             NTCPtype=NTCPtype, NTCPtd50=NTCPtd50, NTCPn=NTCPn, NTCPm=NTCPm, NTCPgamma50=NTCPgamma50, NTCPs=NTCPs,
+                             TCPtype=NTCPtype,  TCPtcd50=NTCPtd50,  TCPn=NTCPn,  TCPm=NTCPm,  TCPgamma50=NTCPgamma50,  TCPs=NTCPs)
                 argL <- Filter(Negate(is.null), argL)
                 metr <- do.call(getMetric, argL)
                 metr$observed <- round(metr$observed, 2)
@@ -334,11 +335,12 @@ shinyApp(
                 NULL
             }
         })#, options=list(pageLength=25))
-        
+
         output$saveMetrics <- downloadHandler(
             filename=function() { "metrics.txt" },
             content=function(file) {
                 dvh       <- DVH()$DVH
+                # browser()
                 sortOpts  <- c('1'="observed", '2'="structure", '3'="metric", '4'="patID")
                 splitOpts <- c('1'="metric", '2'="structure", '3'="patID")
                 selMetrics <- if(length(input$metrInput) > 0) {
@@ -365,17 +367,18 @@ shinyApp(
                 } else {
                     NULL
                 }
-                
+
                 interp  <- "linear"
                 EUDa    <- if(input$metrEUDa  != "") { as.numeric(input$metrEUDa)  } else { NULL }
                 EUDfd   <- if(input$metrEUDfd != "") { as.numeric(input$metrEUDfd) } else { NULL }
                 EUDab   <- if(input$metrEUDab != "") { as.numeric(input$metrEUDab) } else { NULL }
-                
-                NTCPtype    <- c("probit", "logit", "poisson")[as.numeric(input$metrNTCPtype)]
+
+                NTCPtype    <- c("probit", "logit", "poisson", "relative_seriality")[as.numeric(input$metrNTCPtype)]
                 NTCPtd50    <- if(input$metrNTCPtd50    != "") { as.numeric(input$metrNTCPtd50)    } else { NULL }
                 NTCPn       <- if(input$metrNTCPn       != "") { as.numeric(input$metrNTCPn)       } else { NULL }
                 NTCPm       <- if(input$metrNTCPm       != "") { as.numeric(input$metrNTCPm)       } else { NULL }
                 NTCPgamma50 <- if(input$metrNTCPgamma50 != "") { as.numeric(input$metrNTCPgamma50) } else { NULL }
+                NTCPs       <- if(input$metrNTCPs       != "") { as.numeric(input$metrNTCPs)       } else { NULL }
                 
                 sortSel <- input$metrSortBy
                 sortBy <- if(length(sortSel) > 0) {
@@ -390,8 +393,8 @@ shinyApp(
                              sortBy=sortBy,
                              interp=interp,
                              EUDa=EUDa, EUDfd=EUDfd, EUDab=EUDab,
-                             NTCPtype=NTCPtype, NTCPtd50=NTCPtd50, NTCPn=NTCPn, NTCPgamma50=NTCPgamma50,
-                             TCPtype=NTCPtype, TCPtcd50=NTCPtd50,  TCPn=NTCPn,  TCPgamma50=NTCPgamma50)
+                             NTCPtype=NTCPtype, NTCPtd50=NTCPtd50, NTCPn=NTCPn, NTCPm=NTCPm, NTCPgamma50=NTCPgamma50, NTCPs=NTCPs,
+                             TCPtype=NTCPtype,  TCPtcd50=NTCPtd50,  TCPn=NTCPn,  TCPm=NTCPm,  TCPgamma50=NTCPgamma50, TCPs=NTCPs)
                 argL <- Filter(Negate(is.null), argL)
                 metr <- do.call(getMetric, argL)
                 dec <- c('1'=".",  '2'=",")[input$saveMetrDec]
@@ -400,7 +403,7 @@ shinyApp(
             },
             contentType='text/plain' # MIME type
         )
-        
+
         #     output$DVHplotOrg <- renderPlot({
         #         dvh <- DVH()$DVH
         #         if(!is.null(dvh)) {
@@ -414,7 +417,7 @@ shinyApp(
         #             NULL
         #         }
         #     })
-        
+
         output$DVHplot <- renderUI({
             dvh       <- DVH()
             byPat     <- input$plotByPat == '1'
@@ -451,12 +454,12 @@ shinyApp(
                     }
                 })
             }
-            
+
             ## weed out NULL components, convert the list to a tagList and return
             plotOutputL <- Filter(Negate(is.null), plotOutputL)
             do.call(tagList, plotOutputL)
         })
-        
+
         ## adapted from Winston Chang: https://gist.github.com/wch/5436415
         ## call renderPlot maxNID times and discard those not required (return NULL)
         ## problem: number of plots should be dynamic -> reactive context required
@@ -486,7 +489,7 @@ shinyApp(
                             sharedNames <- intersect(selStruct, names(dvh$DVHbyStruct))
                             dvh$DVHbyStruct[sharedNames][[localI]]
                         }
-                        
+
                         brush <- input[[paste0("DVHplot", localI, "_brush")]]
                         if(!is.null(brush)) {
                             showDVH(x=x,
@@ -515,7 +518,7 @@ shinyApp(
                         }
                     }
                 })
-                
+
                 ## constraint plot
                 output[[paste0("constraintPlot", localI)]] <- renderPlot({
                     dvh    <- DVH()
@@ -529,7 +532,7 @@ shinyApp(
                     } else {
                         DVHmetrics:::harmoConstrDVH.DVHLstLst(dvh$DVHbyStruct, constr=constr, byPat=byPat)
                     }
-                    
+
                     if(is.null(constr) || (length(xConstrSub$x) < localI)) {
                         NULL
                     } else {
@@ -557,7 +560,7 @@ shinyApp(
                 })
             })
         }
-        
+
         output$saveDVHPDF <- downloadHandler(
             filename=function() { "DVH.pdf" },
             content=function(file) {
@@ -572,7 +575,7 @@ shinyApp(
                 } else {
                     dvh$DVHbyStruct
                 }
-                
+
                 argL <- list(x=x,
                              cumul=cumul,
                              byPat=byPat,
@@ -587,7 +590,7 @@ shinyApp(
             },
             contentType='application/pdf' # MIME type
         )
-        
+
         makeDVHJPG <- function(fName, dvh, byPat, rel, cumul, selPat, selStruct, thresh) {
             argL <- list(x=dvh,
                          cumul=cumul,
@@ -600,7 +603,7 @@ shinyApp(
             do.call(showDVH, argL)
             dev.off()
         }
-        
+
         output$saveDVHJPG <- downloadHandler(
             filename=function() { "DVH_JPGs.zip" },
             content=function(file) {
@@ -615,7 +618,7 @@ shinyApp(
                 } else {
                     dvh$DVHbyStruct
                 }
-                
+
                 selPat    <- getStrIDs(dvh$DVH, what="patient")[  as.numeric(input$plotSelPat)]
                 selStruct <- getStrIDs(dvh$DVH, what="structure")[as.numeric(input$plotSelStruct)]
                 nFiles <- if(byPat) {
@@ -623,12 +626,12 @@ shinyApp(
                 } else {
                     sum(selStruct %in% names(x))
                 }
-                
+
                 ## write all JPEGs into temporary directory and zip them
                 fNames <- paste0("DVH_", sprintf("%02d", seq_len(nFiles)), ".jpg")
                 tmpdir <- tempdir()
                 setwd(tmpdir)
-                
+
                 for(i in seq_along(fNames)) {
                     fN         <- fNames[i]
                     selPatI    <- if(byPat) { selPat[i] } else { selPat }
@@ -637,7 +640,7 @@ shinyApp(
                                selPat=selPatI, selStruct=selStructI,
                                addMSD=addMSD, thresh=thresh)
                 }
-                
+
                 zip(zipfile=file, files=fNames)
                 if(file.exists(paste0(file, ".zip"))) {
                     file.rename(paste0(file, ".zip"), file)
@@ -645,7 +648,7 @@ shinyApp(
             },
             contentType = "application/zip"
         )
-        
+
         output$saveDVHMSD <- downloadHandler(
             filename=function() { "DVH_M_SD.txt" },
             content=function(file) {
@@ -657,10 +660,10 @@ shinyApp(
                 } else {
                     dvh$DVHbyStruct
                 }
-                
+
                 selPat    <- getStrIDs(dvh$DVH, what="patient")[  as.numeric(input$plotSelPat)]
                 selStruct <- getStrIDs(dvh$DVH, what="structure")[as.numeric(input$plotSelStruct)]
-                
+
                 argL <- list(x=x,
                              fun=list(mean=mean, median=median, min=min, max=max, sd=sd),
                              byPat=byPat,
@@ -677,7 +680,7 @@ shinyApp(
             },
             contentType='text/plain' # MIME type
         )
-        
+
         ## reactive conductor
         DVHconstr <- reactive({
             input$applyConstraints
@@ -715,17 +718,17 @@ shinyApp(
                 } else {
                     NULL
                 }
-                
+
                 if(!is.null(constr)) {
                     cNames <- tolower(names(constr))
                     cNames[cNames == "patid"] <- "patID"
                     constr <- setNames(constr, cNames)
                 }
-                
+
                 return(constr)
             })
         })
-        
+
         output$constraints <- DT::renderDataTable({
             constr <- DVHconstr()
             dvh    <- DVH()$DVH
@@ -734,13 +737,13 @@ shinyApp(
             EUDa   <- if(input$constrEUDa  != "") { as.numeric(input$constrEUDa)  } else { NULL }
             EUDfd  <- if(input$constrEUDfd != "") { as.numeric(input$constrEUDfd) } else { NULL }
             EUDab  <- if(input$constrEUDab != "") { as.numeric(input$constrEUDab) } else { NULL }
-            
+
             NTCPtype    <- c("probit", "logit", "poisson")[as.numeric(input$constrNTCPtype)]
             NTCPtd50    <- if(input$constrNTCPtd50    != "") { as.numeric(input$constrNTCPtd50)    } else { NULL }
             NTCPn       <- if(input$constrNTCPn       != "") { as.numeric(input$constrNTCPn)       } else { NULL }
             NTCPm       <- if(input$constrNTCPm       != "") { as.numeric(input$constrNTCPm)       } else { NULL }
             NTCPgamma50 <- if(input$constrNTCPgamma50 != "") { as.numeric(input$constrNTCPgamma50) } else { NULL }
-            
+
             sortOpts <- c('1'="compliance", '2'="dstMin", '3'="deltaV", '4'="deltaD",
                           '5'="observed", '6'="patID", '7'="structure", '8'="constraint")
             sortSel  <- input$constrSortBy
@@ -749,7 +752,7 @@ shinyApp(
             } else {
                 "none"
             }
-            
+
             if(!is.null(constr) && !is.null(dvh)) {
                 argL <- list(x=dvh,
                              constr=constr, byPat=TRUE, interp=interp,
@@ -769,9 +772,9 @@ shinyApp(
             } else {
                 NULL
             }
-            
+
         })#, options=list(pageLength=25))
-        
+
         #     output$constraintPlotOrg <- renderPlot({
         #         constr <- DVHconstr()
         #         dvh    <- DVH()$DVH
@@ -785,7 +788,7 @@ shinyApp(
         #             NULL
         #         }
         #     })
-        
+
         output$constraintPlot <- renderUI({
             dvh    <- DVH()
             constr <- DVHconstr()
@@ -795,7 +798,7 @@ shinyApp(
             } else {
                 DVHmetrics:::harmoConstrDVH.DVHLstLst(dvh$DVHbyStruct, constr=constr, byPat=byPat)
             }
-            
+
             plotOutputL <- lapply(seq_along(xConstrSub$x), function(i) {
                 plotName <- paste0("constraintPlot", i)
                 plotOutput(plotName,
@@ -804,11 +807,11 @@ shinyApp(
                                            clip=TRUE,
                                            resetOnNew=FALSE))
             })
-            
+
             ## convert the list to a tagList and return
             do.call(tagList, plotOutputL)
         })
-        
+
         output$saveConstrTxt <- downloadHandler(
             filename=function() { "constraints.txt" },
             content=function(file) {
@@ -816,13 +819,13 @@ shinyApp(
                 EUDa   <- if(input$constrEUDa  != "") { as.numeric(input$constrEUDa)  } else { NULL }
                 EUDfd  <- if(input$constrEUDfd != "") { as.numeric(input$constrEUDfd) } else { NULL }
                 EUDab  <- if(input$constrEUDab != "") { as.numeric(input$constrEUDab) } else { NULL }
-                
+
                 NTCPtype    <- c("probit", "logit", "poisson")[as.numeric(input$constrNTCPtype)]
                 NTCPtd50    <- if(input$constrNTCPtd50    != "") { as.numeric(input$constrNTCPtd50)    } else { NULL }
                 NTCPn       <- if(input$constrNTCPn       != "") { as.numeric(input$constrNTCPn)       } else { NULL }
                 NTCPm       <- if(input$constrNTCPm       != "") { as.numeric(input$constrNTCPm)       } else { NULL }
                 NTCPgamma50 <- if(input$constrNTCPgamma50 != "") { as.numeric(input$constrNTCPgamma50) } else { NULL }
-                
+
                 argL <- list(x=DVH()$DVH,
                              constr=DVHconstr(), interp=interp,
                              EUDa=EUDa, EUDfd=EUDfd, EUDab=EUDab,
@@ -836,7 +839,7 @@ shinyApp(
             },
             contentType='text/plain' # MIME type
         )
-        
+
         output$saveConstrPDF <- downloadHandler(
             filename=function() { "constraints.pdf" },
             content=function(file) {
@@ -852,7 +855,7 @@ shinyApp(
             },
             contentType='application/pdf' # MIME type
         )
-        
+
         makeConstrJPG <- function(fName, dvh, constr, byPat, thresh, rel) {
             argL <- list(x=dvh,
                          constr=constr,
@@ -863,7 +866,7 @@ shinyApp(
             do.call(showConstraint, argL)
             dev.off()
         }
-        
+
         output$saveConstrJPG <- downloadHandler(
             filename=function() { "constraints.zip" },
             content=function(file) {
@@ -877,21 +880,21 @@ shinyApp(
                 } else {
                     dvh$DVHbyStruct
                 }
-                
+
                 xConstrSub <- DVHmetrics:::harmoConstrDVH.DVHLstLst(x, constr=constr, byPat=byPat)
                 nFiles     <- length(xConstrSub$x)
-                
+
                 ## write all JPEGs into temporary directory and zip them
                 fNames <- paste0("DVH_", sprintf("%02d", seq_len(nFiles)), ".jpg")
                 tmpdir <- tempdir()
                 setwd(tmpdir)
-                
+
                 for(i in seq_along(fNames)) {
                     fN <- fNames[i]
                     makeConstrJPG(fN, dvh=xConstrSub$x, constr=xConstrSub$constr,
                                   byPat=byPat, rel=rel, thresh=thresh)
                 }
-                
+
                 zip(zipfile=file, files=fNames)
                 if(file.exists(paste0(file, ".zip"))) {
                     file.rename(paste0(file, ".zip"), file)
@@ -899,7 +902,7 @@ shinyApp(
             },
             contentType = "application/zip"
         )
-        
+
         output$BED <- renderPrint({
             if(input$BEDtype %in% c('1', '2')) {
                 D <- if(input$BED_BED_D  != "") {
@@ -959,7 +962,7 @@ shinyApp(
                     NULL
                 }
             }
-            
+
             if(input$BEDtype == '1') {
                 getBED(D=D, fd=fd, fn=fn, ab=ab)
             } else if(input$BEDtype == '2') {
